## History

0.7.0
----------------------

* [pre-commit](https://pre-commit.com/) support (by [@tzoiker](https://github.com/tzoiker))


0.6.2
----------------------

* isort: keep line breaks before local imports

0.6.1
----------------------

* Fix isort imports grouping

0.6.0
----------------------

* Bump isort to 5.4.2
* Use parentheses in multiline imports

0.5.0
----------------------

* Add autoflake formatter
* Add trim formatter

0.4.0
----------------------

* Minimum python version option
* Pyupgrade options
* Detecting and skipping virtualenv


0.3.0
----------------------

* Multiprocessing support (by [@mosquito](https://github.com/mosquito))


0.2.0
-----------------------

* Pre-commit hook
* Some formating options


0.1.0 (2020-04-06)
------------------------

* First release on PyPI.
